package javax.swing.plaf.basic;

import java.awt.Component;
import javax.swing.border.Border;
import javax.swing.border.AbstractBorder;
import javax.swing.LookAndFeel;
import javax.swing.JPanel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.PanelUI;

public class BasicPanelUI extends PanelUI
{
    private static PanelUI panelUI;
    
    public BasicPanelUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        if (BasicPanelUI.panelUI == null) {
            BasicPanelUI.panelUI = new BasicPanelUI();
        }
        return BasicPanelUI.panelUI;
    }
    
    @Override
    public void installUI(JComponent component) {
        JPanel c = (JPanel)component;
        super.installUI(c);
        this.installDefaults(c);
    }
    
    @Override
    public void uninstallUI(JComponent c) {
        this.uninstallDefaults((JPanel)c);
        super.uninstallUI(c);
    }
    
    protected void installDefaults(JPanel c) {
        LookAndFeel.installColorsAndFont(c, "Panel.background", "Panel.foreground", "Panel.font");
        LookAndFeel.installBorder(c, "Panel.border");
        LookAndFeel.installProperty(c, "opaque", Boolean.TRUE);
    }
    
    protected void uninstallDefaults(JPanel c) {
        LookAndFeel.uninstallBorder(c);
    }
    
    @Override
    public int getBaseline(JComponent component, int n, int n2) {
        super.getBaseline(component, n, n2);
        Border border = component.getBorder();
        if ((border instanceof AbstractBorder)) {
            return ((AbstractBorder)border).getBaseline(component, n, n2);
        }
        return -1;
    }
    
    @Override
    public Component.BaselineResizeBehavior getBaselineResizeBehavior(JComponent component) {
        super.getBaselineResizeBehavior(component);
        Border border = component.getBorder();
        if ((border instanceof AbstractBorder)) {
            return ((AbstractBorder)border).getBaselineResizeBehavior(component);
        }
        return Component.BaselineResizeBehavior.OTHER;
    }
}
